@@ -102,7 +102,8 @@ def write_tanks(network: Network, fid: TextIOWrapper):
     logger.debug("Writing Tanks section")
     print("[TANKS]", file=fid)
     print(
-        ";id elevation initlevel minlevel maxlevel diam minvolume volumecurve", file=fid
+        ";id elevation initlevel minlevel maxlevel diameter minvolume volumecurve",
+        file=fid,
     )
     for t in get_tanks(network):
         print(t.id, end=" ", file=fid)
@@ -110,11 +111,11 @@ def write_tanks(network: Network, fid: TextIOWrapper):
         print(t.initlevel, end=" ", file=fid)
         print(t.minlevel, end=" ", file=fid)
         print(t.maxlevel, end=" ", file=fid)
-        print(t.diam, end=" ", file=fid)
+        print(t.diameter, end=" ", file=fid)
         if t.minvolume is not None:
             print(t.minvolume, end=" ", file=fid)
         if t.volumecurve is not None:
-            print(t.volumecurve, end=" ", file=fid)
+            print(t.volumecurve.id, end=" ", file=fid)
         if t.comment is not None:
             print(";", t.comment, end=" ", file=fid)
         print("\n", end=" ", file=fid)
